% This file is part of the Attempto Parsing Engine (APE).
% Copyright 2008, Attempto Group, University of Zurich (see http://attempto.ifi.uzh.ch).
%
% The Attempto Parsing Engine (APE) is free software: you can redistribute it and/or modify it
% under the terms of the GNU Lesser General Public License as published by the Free Software
% Foundation, either version 3 of the License, or (at your option) any later version.
%
% The Attempto Parsing Engine (APE) is distributed in the hope that it will be useful, but WITHOUT
% ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
% PURPOSE. See the GNU Lesser General Public License for more details.
%
% You should have received a copy of the GNU Lesser General Public License along with the Attempto
% Parsing Engine (APE). If not, see http://www.gnu.org/licenses/.


:- module(drs_to_ace, [drs_to_ace/2]).

/** <module> DRS to ACE verbalizer

Translate an Attempto DRS into Attempto Controlled English (ACE).
The result is either in Core ACE or in NP ACE.

@author Kaarel Kaljurand
@version 2009-04-17
*/

:- use_module(drs_to_coreace).
:- use_module(drs_to_npace).


%% drs_to_ace(+Drs:drs, -AceSentenceList:list) is det.
%
% @param Drs is an Attempto DRS (untyped)
% @param AceText is a list of ACE sentences
%
% BUG: As Drace NP might take very long (due to a bug?) we add
% a timeout to fail if it takes longer than, say, 0.5 seconds.
%
drs_to_ace(Drs, AceSentenceList) :-
	catch(call_with_time_limit(0.5, drs_to_npace:drs_to_npace(Drs, AceSentenceList)), _, fail),
	AceSentenceList \= [],
	\+ member('ERROR', AceSentenceList),
	!.

drs_to_ace(Drs, AceSentenceList) :-
	drs_to_coreace:drs_to_coreace(Drs, AceSentenceList).
